@@ -574,6 +574,7 @@ _check_file (GFile *mount_root, const char *file_path,
 	return _check_file_common (file, must_be_executable);
 }
 
+#ifdef NAUTILUS_AUTORUN_SUPPORTS_AUTORUN_EXE
 static gboolean
 _check_file_case_insensitive (GFile *mount_root, const char *file_path,
                               gboolean must_be_executable)
@@ -582,6 +583,7 @@ _check_file_case_insensitive (GFile *mount_root, const char *file_path,
 	GFile *file = nautilus_find_file_insensitive (mount_root, file_path);
 	return _check_file_common (file, must_be_executable);
 }
+#endif
 
 /**
  * _g_mount_guess_content_type:
@@ -733,8 +735,14 @@ _g_mount_guess_content_type (GMount              *mount,
 	    (_check_file (root, ".autorun", TRUE) ||
 	     _check_file (root, "autorun", TRUE) ||
 	     _check_file (root, "autorun.sh", TRUE) ||
+#ifdef NAUTILUS_AUTORUN_SUPPORTS_AUTORUN_EXE
+	     /* TODO */
 	     _check_file_case_insensitive (root, "autorun.exe", TRUE) ||
-	     _check_file_case_insensitive (root, "autorun.inf", FALSE))) {
+	     _check_file_case_insensitive (root, "autorun.inf", FALSE)))
+#else
+	    0))
+#endif
+	{
 		/* http://standards.freedesktop.org/autostart-spec/autostart-spec-latest.html */
 		
 		/* http://bugzilla.gnome.org/show_bug.cgi?id=509823#c3 for the autorun.exe and autorun.inf stuff */
@@ -1095,14 +1103,14 @@ show_dialog:
 	} else if (strcmp (x_content_type, "x-content/image-picturecd") == 0) {
 		media_greeting = _("You have just inserted a Picture CD.");
 	} else if (strcmp (x_content_type, "x-content/image-dcf") == 0) {
-		media_greeting = _("You have just inserted media with digital photos.");
+		media_greeting = _("You have just inserted a medium with digital photos.");
 	} else if (strcmp (x_content_type, "x-content/audio-player") == 0) {
 		media_greeting = _("You have just inserted a digital audio player.");
 	} else if (strcmp (x_content_type, "x-content/software") == 0) {
-		media_greeting = _("You have just inserted media with software intended to be automatically started.");
+		media_greeting = _("You have just inserted a medium with software intended to be automatically started.");
 	} else {
 		/* fallback to generic greeting */
-		media_greeting = _("You have just inserted media.");
+		media_greeting = _("You have just inserted a medium.");
 	}
 	markup = g_strdup_printf ("<big><b>%s %s</b></big>", media_greeting, _("Choose what application to launch."));
 	gtk_label_set_markup (GTK_LABEL (label), markup);
@@ -1345,70 +1353,60 @@ nautilus_autorun_get_cached_x_content_types_for_mount (GMount      *mount)
 	return NULL;
 }
 
-
-static GList *inhibit_mount_handling_for = NULL;
-
-
 static gboolean
-remove_inhibit_file_cb (gpointer data)
-{
-	GFile *file = data;
-	GList *l;
-
-	l = g_list_find (inhibit_mount_handling_for, file);
-	if (l != NULL) {
-		inhibit_mount_handling_for = g_list_delete_link (inhibit_mount_handling_for, l);
-		g_object_unref (file);
-	}
-	
-	return FALSE;
-}
-
-void
-nautilus_inhibit_autorun_for_file (GFile *file)
-{
-	inhibit_mount_handling_for = g_list_prepend (inhibit_mount_handling_for, g_object_ref (file));
-	g_timeout_add_full (0,
-			    5000,
-			    remove_inhibit_file_cb,
-			    g_object_ref (file),
-			    g_object_unref);
-}
-
-static gboolean
-remove_inhibit_volume (gpointer data)
+remove_allow_volume (gpointer data)
 {
 	GVolume *volume = data;
 
-	g_object_set_data (G_OBJECT (volume), "nautilus-inhibit-autorun", NULL);
+	g_object_set_data (G_OBJECT (volume), "nautilus-allow-autorun", NULL);
 	return FALSE;
 }
 
 void
-nautilus_inhibit_autorun_for_volume (GVolume *volume)
+nautilus_allow_autorun_for_volume (GVolume *volume)
 {
-	g_object_set_data (G_OBJECT (volume), "nautilus-inhibit-autorun", GINT_TO_POINTER (1));
-	g_timeout_add_full (0,
-			    5000,
-			    remove_inhibit_volume,
-			    g_object_ref (volume),
-			    g_object_unref);
+	g_object_set_data (G_OBJECT (volume), "nautilus-allow-autorun", GINT_TO_POINTER (1));
+}
+
+void
+nautilus_allow_autorun_for_volume_finish (GVolume *volume)
+{
+	if (g_object_get_data (G_OBJECT (volume), "nautilus-allow-autorun") != NULL) {
+		g_timeout_add_full (0,
+				    5000,
+				    remove_allow_volume,
+				    g_object_ref (volume),
+				    g_object_unref);
+	}
+}
+
+static gboolean
+should_skip_native_mount_root (GFile *root)
+{
+	char *path;
+	gboolean should_skip;
+
+	/* skip any mounts in hidden directory hierarchies */
+	path = g_file_get_path (root);
+	should_skip = strstr (path, "/.") != NULL;
+	g_free (path);
+
+	return should_skip;
 }
 
 static gboolean
 should_autorun_mount (GMount *mount)
 {
-	GFile *root, *file;
-	GList *l;
+	GFile *root;
 	GVolume *enclosing_volume;
 	gboolean ignore_autorun;
 
-	ignore_autorun = FALSE;
+	ignore_autorun = TRUE;
 	enclosing_volume = g_mount_get_volume (mount);
 	if (enclosing_volume != NULL) {
-		if (g_object_get_data (G_OBJECT (enclosing_volume), "nautilus-inhibit-autorun") != NULL) {
-			ignore_autorun = TRUE;
-			g_object_set_data (G_OBJECT (enclosing_volume), "nautilus-inhibit-autorun", NULL);
+		if (g_object_get_data (G_OBJECT (enclosing_volume), "nautilus-allow-autorun") != NULL) {
+			ignore_autorun = FALSE;
+			g_object_set_data (G_OBJECT (enclosing_volume), "nautilus-allow-autorun", NULL);
 		}
 	}
 
@@ -1421,21 +1419,9 @@ should_autorun_mount (GMount *mount)
 	
 	root = g_mount_get_root (mount);
 
-	for (l = inhibit_mount_handling_for; l != NULL; l = l->next) {
-		file = l->data;
-		if (g_file_has_prefix (file, root)) {
-			ignore_autorun = TRUE;
-			
-			inhibit_mount_handling_for = g_list_delete_link (inhibit_mount_handling_for, l);
-			g_object_unref (file);
-			
-			break;
-		}
-	}
-
 	/* only do autorun on local files or files where g_volume_should_automount() returns TRUE */
 	ignore_autorun = TRUE;
-	if (g_file_is_native (root) || 
+	if ((g_file_is_native (root) && !should_skip_native_mount_root (root)) || 
 	    (enclosing_volume != NULL && g_volume_should_automount (enclosing_volume))) {
 		ignore_autorun = FALSE;
 	}
