@@ -35,9 +35,7 @@
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkseparatormenuitem.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -370,7 +368,7 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	const char *dropped_uri;
 	GFile *target, *dropped;
 	GdkDragAction actions;
-	NautilusFile *target_file;
+	NautilusFile *dropped_file, *target_file;
 
 	if (target_uri_string == NULL) {
 		*action = 0;
@@ -391,7 +389,8 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	}
 	
 	dropped_uri = ((NautilusDragSelectionItem *)items->data)->uri;
-	target_file = nautilus_file_get_existing_by_uri (dropped_uri);
+	dropped_file = nautilus_file_get_existing_by_uri (dropped_uri);
+	target_file = nautilus_file_get_existing_by_uri (target_uri_string);
 	
 	/*
 	 * Check for trash URI.  We do a find_directory for any Trash directory.
@@ -404,13 +403,15 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 			*action = GDK_ACTION_MOVE;
 		}
 
+		nautilus_file_unref (dropped_file);
 		nautilus_file_unref (target_file);
 		return;
 
-	} else if (target_file != NULL && nautilus_file_is_launcher (target_file)) {
+	} else if (dropped_file != NULL && nautilus_file_is_launcher (dropped_file)) {
 		if (actions & GDK_ACTION_MOVE) {
 			*action = GDK_ACTION_MOVE;
 		}
+		nautilus_file_unref (dropped_file);
 		nautilus_file_unref (target_file);
 		return;
 	} else if (eel_uri_is_desktop (target_uri_string)) {
@@ -421,13 +422,22 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 				*action = GDK_ACTION_MOVE;
 			}
 			
+			g_free (target);
+			nautilus_file_unref (dropped_file);
 			nautilus_file_unref (target_file);
 			return;
 		}
+	} else if (target_file != NULL && nautilus_file_is_archive (target_file)) {
+		*action = GDK_ACTION_COPY;
+
+		nautilus_file_unref (dropped_file);
+		nautilus_file_unref (target_file);
+		return;
 	} else {
 		target = g_file_new_for_uri (target_uri_string);
 	}
 
+	nautilus_file_unref (dropped_file);
 	nautilus_file_unref (target_file);
 	
 	/* Compare the first dropped uri with the target uri for same fs match. */
@@ -455,6 +465,18 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	
 }
 
+GdkDragAction
+nautilus_drag_default_drop_action_for_uri_list (GdkDragContext *context,
+						const char *target_uri_string)
+{
+	if (eel_uri_is_trash (target_uri_string) && (context->actions & GDK_ACTION_MOVE)) {
+		/* Only move to Trash */
+		return GDK_ACTION_MOVE;
+	} else {
+		return context->suggested_action;
+	}
+}
+
 /* Encode a "x-special/gnome-icon-list" selection.
    Along with the URIs of the dragged files, this encodes
    the location and size of each icon relative to the cursor.
