@@ -27,7 +27,7 @@
 
 #include <glib-object.h>
 #include <libnautilus-private/nautilus-view.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 #include "../src/nautilus-bookmark-list.h"
 
 G_BEGIN_DECLS
@@ -129,7 +129,7 @@ struct _NautilusWindowInfoIface
 				       NautilusWindowShowHiddenFilesMode mode);
 
 	void   (* open_location)      (NautilusWindowInfo *window,
-				       const char *location,
+				       GFile *location,
 				       NautilusWindowOpenMode mode,
 				       NautilusWindowOpenFlags flags,
 				       GList *selection);
@@ -147,7 +147,7 @@ void                              nautilus_window_info_report_view_failed
 										 NautilusView                      *view);
 void                              nautilus_window_info_report_selection_changed (NautilusWindowInfo                *window);
 void                              nautilus_window_info_open_location            (NautilusWindowInfo                *window,
-										 const char                        *location,
+										 GFile                             *location,
 										 NautilusWindowOpenMode             mode,
 										 NautilusWindowOpenFlags            flags,
 										 GList                             *selection);
