@@ -28,10 +28,7 @@
 #ifndef FM_DIRECTORY_VIEW_H
 #define FM_DIRECTORY_VIEW_H
 
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <eel/eel-background.h>
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-file.h>
@@ -373,6 +370,7 @@ void                fm_directory_view_move_copy_items                  (const GL
 									int               x,
 									int               y,
 									FMDirectoryView  *view);
+GdkAtom	            fm_directory_view_get_copied_files_atom            (FMDirectoryView  *view);
 
 /* Wrappers for signal emitters. These are normally called 
  * only by FMDirectoryView itself. They have corresponding signals
@@ -414,7 +412,8 @@ void                fm_directory_view_pop_up_background_context_menu   (FMDirect
 void                fm_directory_view_pop_up_selection_context_menu    (FMDirectoryView  *view,
 									GdkEventButton   *event); 
 void                fm_directory_view_pop_up_location_context_menu     (FMDirectoryView  *view,
-									GdkEventButton   *event); 
+									GdkEventButton   *event,
+									const char       *location); 
 void                fm_directory_view_send_selection_change            (FMDirectoryView *view);
 gboolean            fm_directory_view_should_show_file                 (FMDirectoryView  *view,
 									NautilusFile     *file);
