@@ -39,14 +39,7 @@
 #include <eel/eel-vfs-extensions.h>
 #include <errno.h>
 #include <fcntl.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkradiomenuitem.h>
-#include <gtk/gtkradioaction.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkstock.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <libnautilus-private/nautilus-directory-background.h>
@@ -1526,7 +1519,7 @@ fm_icon_view_start_renaming_file (FMDirectoryView *view,
 static const GtkActionEntry icon_view_entries[] = {
   /* name, stock id, label */  { "Arrange Items", NULL, N_("Arran_ge Items") }, 
   /* name, stock id */         { "Stretch", NULL,
-  /* label, accelerator */       N_("Str_etch Icon..."), NULL,
+  /* label, accelerator */       N_("Stretc_h Icon..."), NULL,
   /* tooltip */                  N_("Make the selected icon stretchable"),
                                  G_CALLBACK (action_stretch_callback) },
   /* name, stock id */         { "Unstretch", NULL,
@@ -2540,6 +2533,9 @@ icon_view_move_copy_items (NautilusIconContainer *container,
 			   int x, int y,
 			   FMDirectoryView *view)
 {
+	nautilus_clipboard_clear_if_colliding_uris (GTK_WIDGET (view),
+						    item_uris,
+						    fm_directory_view_get_copied_files_atom (view));
 	fm_directory_view_move_copy_items (item_uris, relative_item_points, target_dir,
 		copy_action, x, y, view);
 }
