@@ -32,16 +32,10 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
-#include <gtk/gtktreednd.h>
-#include <gtk/gtktreesortable.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libnautilus-private/nautilus-dnd.h>
-
-#if GLIB_CHECK_VERSION (2, 13, 0)
 #include <glib/gsequence.h>
-#else
-#include <gsequence/gsequence.h>
-#endif
 
 enum {
 	SUBDIRECTORY_UNLOADED,
