@@ -37,16 +37,7 @@
 #include <eel/eel-gtk-macros.h>
 #include <gdk/gdkcursor.h>
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkbindings.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
+#include <gtk/gtk.h>
 #include <libegg/eggtreemultidnd.h>
 #include <glib/gi18n.h>
 #include <libgnome/gnome-macros.h>
@@ -1152,12 +1143,17 @@ move_copy_items_callback (NautilusTreeViewDragDest *dest,
 			  gpointer user_data)
 
 {
+	FMDirectoryView *view = user_data;
+
+	nautilus_clipboard_clear_if_colliding_uris (GTK_WIDGET (view),
+						    item_uris,
+						    fm_directory_view_get_copied_files_atom (view));
 	fm_directory_view_move_copy_items (item_uris,
 					   NULL,
 					   target_uri,
 					   action,
 					   x, y,
-					   FM_DIRECTORY_VIEW (user_data));
+					   view);
 }
 
 static void
