@@ -40,25 +40,12 @@
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-preferences.h>
 #include <eel/eel-stock-dialogs.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtktreemodelsort.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtkseparatormenuitem.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkmenushell.h>
-#include <gtk/gtkclipboard.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-popup-menu.h>
+#include <libnautilus-private/nautilus-clipboard.h>
 #include <libnautilus-private/nautilus-clipboard-monitor.h>
 #include <libnautilus-private/nautilus-desktop-icon-file.h>
 #include <libnautilus-private/nautilus-debug-log.h>
@@ -138,6 +125,8 @@ static void  fm_tree_view_iface_init        (NautilusSidebarIface         *iface
 static void  sidebar_provider_iface_init    (NautilusSidebarProviderIface *iface);
 static GType fm_tree_view_provider_get_type (void);
 
+static void create_popup_menu (FMTreeView *view);
+
 G_DEFINE_TYPE_WITH_CODE (FMTreeView, fm_tree_view, GTK_TYPE_SCROLLED_WINDOW,
 			 G_IMPLEMENT_INTERFACE (NAUTILUS_TYPE_SIDEBAR,
 						fm_tree_view_iface_init));
@@ -570,7 +559,10 @@ move_copy_items_callback (NautilusTreeViewDragDest *dest,
 	FMTreeView *view;
 
 	view = FM_TREE_VIEW (user_data);
-
+	
+	nautilus_clipboard_clear_if_colliding_uris (GTK_WIDGET (view),
+						    item_uris,
+						    copied_files_atom);
 	nautilus_file_operations_copy_move
 		(item_uris,
 		 NULL,
@@ -637,16 +629,12 @@ clipboard_contents_received_callback (GtkClipboard     *clipboard,
 	view = FM_TREE_VIEW (data);
 
 	if (selection_data->type == copied_files_atom
-	    && selection_data->length > 0) {
+	    && selection_data->length > 0 &&
+	    view->details->popup != NULL) {
 		gtk_widget_set_sensitive (view->details->popup_paste, TRUE);
 	}
-}
 
-static GtkClipboard *
-get_clipboard (GtkWidget *widget)
-{
-	return gtk_clipboard_get_for_display (gtk_widget_get_display (widget),
-					      GDK_SELECTION_CLIPBOARD);
+	g_object_unref (view);
 }
 
 static gboolean
@@ -697,7 +685,9 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 		gtk_tree_view_get_cursor (view->details->tree_widget, &cursor_path, NULL);
 		gtk_tree_view_set_cursor (view->details->tree_widget, path, NULL, FALSE);
 		gtk_tree_path_free (path);
-		
+
+		create_popup_menu (view);
+
 		gtk_widget_set_sensitive (view->details->popup_open_in_new_window,
 			nautilus_file_is_directory (view->details->popup_file));
 		gtk_widget_set_sensitive (view->details->popup_create_folder,
@@ -706,9 +696,9 @@ button_pressed_callback (GtkTreeView *treeview, GdkEventButton *event,
 		gtk_widget_set_sensitive (view->details->popup_paste, FALSE);
 		if (nautilus_file_is_directory (view->details->popup_file) &&
 			nautilus_file_can_write (view->details->popup_file)) {
-			gtk_clipboard_request_contents (get_clipboard (GTK_WIDGET (view->details->tree_widget)),
+			gtk_clipboard_request_contents (nautilus_clipboard_get (GTK_WIDGET (view->details->tree_widget)),
 							copied_files_atom,
-							clipboard_contents_received_callback, view);
+							clipboard_contents_received_callback, g_object_ref (view));
 		}
 		can_move_file_to_trash = nautilus_file_can_trash (view->details->popup_file);
 		gtk_widget_set_sensitive (view->details->popup_trash, can_move_file_to_trash);
@@ -880,7 +870,7 @@ copy_or_cut_files (FMTreeView *view,
 	
 	clipboard_string = convert_file_to_string (view->details->popup_file, cut);
 	
-	gtk_clipboard_set_with_data (get_clipboard (GTK_WIDGET (view->details->tree_widget)),
+	gtk_clipboard_set_with_data (nautilus_clipboard_get (GTK_WIDGET (view->details->tree_widget)),
 				     clipboard_targets, G_N_ELEMENTS (clipboard_targets),
 				     get_clipboard_callback, clear_clipboard_callback,
 				     clipboard_string);
@@ -917,55 +907,17 @@ fm_tree_view_copy_cb (GtkWidget *menu_item,
 	copy_or_cut_files (view, FALSE);
 }
 
-static GList *
-convert_lines_to_str_list (char **lines, gboolean *cut)
-{
-	int i;
-	GList *result;
-
-	*cut = FALSE;
-
-	if (lines[0] == NULL) {
-		return NULL;
-	}
-
-	if (strcmp (lines[0], "cut") == 0) {
-		*cut = TRUE;
-	} else if (strcmp (lines[0], "copy") != 0) {
-		return NULL;
-	}
-
-	result = NULL;
-	for (i = 1; lines[i] != NULL; i++) {
-		result = g_list_prepend (result, g_strdup (lines[i]));
-	}
-	return g_list_reverse (result);
-}
-
 static void
 paste_clipboard_data (FMTreeView *view,
 		      GtkSelectionData *selection_data,
 		      char *destination_uri)
 {
-	char **lines;
 	gboolean cut;
 	GList *item_uris;
 
 	cut = FALSE;
-	if (selection_data->type != copied_files_atom
-	    || selection_data->length <= 0) {
-		item_uris = NULL;
-	} else {
-		/* Not sure why it's legal to assume there's an extra byte
-		 * past the end of the selection data that it's safe to write
-		 * to. But gtk_editable_selection_received does this, so I
-		 * think it is OK.
-		 */
-		selection_data->data[selection_data->length] = '\0';
-		lines = g_strsplit (selection_data->data, "\n", 0);
-		item_uris = convert_lines_to_str_list (lines, &cut);
-		g_strfreev (lines);
-	}
+	item_uris = nautilus_clipboard_get_uri_list_from_selection_data (selection_data, &cut,
+									 copied_files_atom);
 
 	if (item_uris == NULL|| destination_uri == NULL) {
 		nautilus_window_info_set_status (view->details->window,
@@ -976,6 +928,13 @@ paste_clipboard_data (FMTreeView *view,
 			 cut ? GDK_ACTION_MOVE : GDK_ACTION_COPY,
 			 GTK_WIDGET (view->details->tree_widget),
 			 NULL, NULL);
+
+		/* If items are cut then remove from clipboard */
+		if (cut) {
+			gtk_clipboard_clear (nautilus_clipboard_get (GTK_WIDGET (view)));
+		}
+		
+		eel_g_list_free_deep (item_uris);
 	}
 }
 
@@ -1000,7 +959,7 @@ static void
 fm_tree_view_paste_cb (GtkWidget *menu_item,
 		       FMTreeView *view)
 {
-	gtk_clipboard_request_contents (get_clipboard (GTK_WIDGET (view->details->tree_widget)),
+	gtk_clipboard_request_contents (nautilus_clipboard_get (GTK_WIDGET (view->details->tree_widget)),
 					copied_files_atom,
 					paste_into_clipboard_received_callback, view);
 }
@@ -1093,6 +1052,11 @@ static void
 create_popup_menu (FMTreeView *view)
 {
 	GtkWidget *popup, *menu_item, *menu_image;
+
+	if (view->details->popup != NULL) {
+		/* already created */
+		return;
+	}
 	
 	popup = gtk_menu_new ();
 	
@@ -1408,15 +1372,14 @@ fm_tree_view_init (FMTreeView *view)
 	
 	view->details->selecting = FALSE;
 
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
-				      filtering_changed_callback, view);
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES,
-				      filtering_changed_callback, view);
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
-				      filtering_changed_callback, view);
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
+						  filtering_changed_callback, view, G_OBJECT (view));
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES,
+						  filtering_changed_callback, view, G_OBJECT (view));
+	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
+						  filtering_changed_callback, view, G_OBJECT (view));
 	
 	view->details->popup_file = NULL;
-	create_popup_menu (view);
 }
 
 static void
@@ -1441,6 +1404,30 @@ fm_tree_view_dispose (GObject *object)
 		view->details->show_selection_idle_id = 0;
 	}
 
+	cancel_activation (view);
+
+	if (view->details->popup != NULL) {
+		gtk_widget_destroy (view->details->popup);
+		view->details->popup = NULL;
+	}
+
+	if (view->details->popup_file != NULL) {
+		nautilus_file_unref (view->details->popup_file);
+		view->details->popup_file = NULL;
+	}
+
+	if (view->details->selection_location != NULL) {
+		g_free (view->details->selection_location);
+		view->details->selection_location = NULL;
+	}
+
+	if (view->details->volume_monitor != NULL) {
+		g_object_unref (view->details->volume_monitor);
+		view->details->volume_monitor = NULL;
+	}
+
+	view->details->window = NULL;
+
 	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
 
@@ -1451,22 +1438,6 @@ fm_tree_view_finalize (GObject *object)
 
 	view = FM_TREE_VIEW (object);
 
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_SHOW_HIDDEN_FILES,
-					 filtering_changed_callback, view);
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_SHOW_BACKUP_FILES,
-					 filtering_changed_callback, view);
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
-					 filtering_changed_callback, view);
-
-	cancel_activation (view);
-	gtk_widget_destroy (view->details->popup);
-
-	if (view->details->selection_location != NULL) {
-		g_free (view->details->selection_location);
-	}
-
-	g_object_unref (view->details->volume_monitor);
-	
 	g_free (view->details);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
