@@ -29,7 +29,6 @@
 #include "nautilus-application.h"
 
 
-#include "file-manager/fm-ditem-page.h"
 #include "file-manager/fm-desktop-icon-view.h"
 #include "file-manager/fm-icon-view.h"
 #include "file-manager/fm-list-view.h"
@@ -67,7 +66,7 @@
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <libgnome/gnome-config.h>
 #include <libgnomeui/gnome-authentication-manager.h>
 #include <libgnomeui/gnome-client.h>
@@ -421,8 +420,6 @@ finish_startup (NautilusApplication *application)
 	/* initialize nautilus modules */
 	nautilus_module_init ();
 
-	nautilus_module_add_type (FM_TYPE_DITEM_PAGE);
-
 	/* attach menu-provider module callback */
 	menu_provider_init_callback ();
 	
@@ -1468,7 +1465,7 @@ mount_removed_callback (GVolumeMonitor *monitor,
 
 			location = nautilus_window_get_location (window);
 
-			if (g_file_has_prefix (location, root)) {
+			if (g_file_equal(location, root) || g_file_has_prefix (location, root)) {
 				close_list = g_list_prepend (close_list, window);
 			} 
 			g_object_unref (location);
