@@ -42,8 +42,7 @@
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomeui/gnome-uidefs.h>
@@ -276,7 +275,7 @@ label_button_pressed_callback (GtkWidget             *widget,
 		return FALSE;
 	}
 
-	nautilus_view_pop_up_location_context_menu (view, event);
+	nautilus_view_pop_up_location_context_menu (view, event, NULL);
 
 	return FALSE;
 }
