@@ -42,10 +42,7 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-self-checks.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtksignal.h>
-#include <gdk/gdk.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gdesktopappinfo.h>
 #include <libgnome/gnome-init.h>
@@ -434,6 +431,8 @@ main (int argc, char *argv[])
 		g_unsetenv ("DESKTOP_STARTUP_ID");
 	}
 
+	autostart_mode = FALSE;
+
 	autostart_id = g_getenv ("DESKTOP_AUTOSTART_ID");
 	if (autostart_id != NULL && *autostart_id != '\0') {
 		autostart_mode = TRUE;
