@@ -46,15 +46,7 @@
 #include <eel/eel-string.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmenubar.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtktoolbar.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtktreemodel.h>
-#include <gtk/gtkliststore.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #ifdef HAVE_X11_XF86KEYSYM_H
 #include <X11/XF86keysym.h>
@@ -116,6 +108,9 @@ static void navigation_bar_cancel_callback           (GtkWidget                *
 static void path_bar_location_changed_callback       (GtkWidget                *widget,
 						      GFile                    *path,
 						      NautilusNavigationWindow *window);
+static void path_bar_path_set_callback               (GtkWidget                *widget,
+						      GFile                    *location,
+						      NautilusNavigationWindow *window);
 static void always_use_location_entry_changed        (gpointer                  callback_data);
 static void always_use_browser_changed               (gpointer                  callback_data);
 
@@ -274,6 +269,8 @@ nautilus_navigation_window_init (NautilusNavigationWindow *window)
 	
 	g_signal_connect_object (window->path_bar, "path_clicked",
 				 G_CALLBACK (path_bar_location_changed_callback), window, 0);
+	g_signal_connect_object (window->path_bar, "path_set",
+				 G_CALLBACK (path_bar_path_set_callback), window, 0);
 	
 	gtk_box_pack_start (GTK_BOX (hbox),
 			    window->path_bar,
@@ -894,7 +891,7 @@ load_view_as_menu (NautilusWindow *window)
              node != NULL; 
              node = node->next, ++index) {
 		info = nautilus_view_factory_lookup (node->data);
-		gtk_combo_box_append_text (combo_box, _(info->view_as_label));
+		gtk_combo_box_append_text (combo_box, _(info->view_combo_label));
 
 		if (nautilus_window_content_view_matches_iid (NAUTILUS_WINDOW (window), (char *)node->data)) {
 			selected_index = index;
@@ -908,7 +905,7 @@ load_view_as_menu (NautilusWindow *window)
 		id = nautilus_window_get_content_view_id (window);
 		info = nautilus_view_factory_lookup (id);
 		gtk_combo_box_append_text (GTK_COMBO_BOX (NAUTILUS_NAVIGATION_WINDOW (window)->view_as_combo_box),
-					   _(info->view_as_label));
+					   _(info->view_combo_label));
 		selected_index = index;
 	}
 
@@ -1027,6 +1024,66 @@ real_set_content_view_widget (NautilusWindow *nautilus_window,
 	}
 }
 
+static gboolean
+path_bar_button_pressed_callback (GtkWidget *widget,
+				  GdkEventButton *event,
+				  NautilusNavigationWindow *window)
+{
+	NautilusView *view;
+	GFile *location;
+	char *uri;
+
+	if (event->button == 3) {
+		view = NAUTILUS_WINDOW (window)->content_view;
+		if (view != NULL) {
+			location = nautilus_path_bar_get_path_for_button (
+				NAUTILUS_PATH_BAR (window->path_bar), widget);
+			if (location != NULL) {
+				uri = g_file_get_uri (location);
+				nautilus_view_pop_up_location_context_menu (
+					view, event, uri);
+				g_object_unref (G_OBJECT (location));
+				g_free (uri);
+				return TRUE;
+			}
+		}
+	}
+
+
+	return FALSE;
+}
+
+static void
+path_bar_path_set_callback (GtkWidget *widget,
+			    GFile *location,
+			    NautilusNavigationWindow *window)
+{
+	GList *children, *l;
+	GtkWidget *child;
+
+	children = gtk_container_get_children (GTK_CONTAINER (widget));
+
+	for (l = children; l != NULL; l = l->next) {
+		child = GTK_WIDGET (l->data);
+
+		if (!GTK_IS_TOGGLE_BUTTON (child)) {
+			continue;
+		}
+
+		if (!g_signal_handler_find (child,
+					    G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+					    0, 0, NULL, 
+					    path_bar_button_pressed_callback,
+					    window)) {
+			g_signal_connect (child, "button-press-event",
+					  G_CALLBACK (path_bar_button_pressed_callback),
+					  window);
+		}
+	}
+
+	g_list_free (children);
+}
+
 static void
 real_set_throbber_active (NautilusWindow *window, gboolean active)
 {
