@@ -24,14 +24,7 @@
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-preferences.h>
 #include <eel/eel-string.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkalignment.h>
-#include <gtk/gtkarrow.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <libnautilus-private/nautilus-file.h>
@@ -43,6 +36,7 @@
 
 enum {
         PATH_CLICKED,
+        PATH_SET,
         LAST_SIGNAL
 };
 
@@ -299,6 +293,15 @@ nautilus_path_bar_class_init (NautilusPathBarClass *path_bar_class)
 		  g_cclosure_marshal_VOID__OBJECT,
 		  G_TYPE_NONE, 1,
 		  G_TYPE_FILE);
+	 path_bar_signals [PATH_SET] =
+		g_signal_new ("path-set",
+		  G_OBJECT_CLASS_TYPE (object_class),
+		  G_SIGNAL_RUN_FIRST,
+		  G_STRUCT_OFFSET (NautilusPathBarClass, path_set),
+		  NULL, NULL,
+		  g_cclosure_marshal_VOID__OBJECT,
+		  G_TYPE_NONE, 1,
+		  G_TYPE_FILE);
 }
 
 
@@ -338,6 +341,9 @@ nautilus_path_bar_finalize (GObject *object)
 		path_bar->desktop_icon = NULL;
 	}
 
+	g_signal_handlers_disconnect_by_func (nautilus_trash_monitor_get (),
+					      trash_state_changed_cb, path_bar);
+
         G_OBJECT_CLASS (nautilus_path_bar_parent_class)->finalize (object);
 }
 
@@ -1532,6 +1538,8 @@ nautilus_path_bar_update_path (NautilusPathBar *path_bar, GFile *file_path)
 
         gtk_widget_pop_composite_child ();
 
+	g_signal_emit (path_bar, path_bar_signals [PATH_SET], 0, file_path);
+
         return result;
 }
 
@@ -1550,7 +1558,25 @@ nautilus_path_bar_set_path (NautilusPathBar *path_bar, GFile *file_path)
 	return nautilus_path_bar_update_path (path_bar, file_path);
 }
 
+GFile *
+nautilus_path_bar_get_path_for_button (NautilusPathBar *path_bar,
+				       GtkWidget       *button)
+{
+	GList *list;
+ 
+	g_return_val_if_fail (NAUTILUS_IS_PATH_BAR (path_bar), NULL);
+	g_return_val_if_fail (GTK_IS_BUTTON (button), NULL);
 
+	for (list = path_bar->button_list; list; list = list->next) {
+		ButtonData *button_data;
+		button_data = BUTTON_DATA (list->data);
+		if (button_data->button == button) {
+			return g_object_ref (button_data->path);
+		}
+	}
+
+	return NULL;
+}
 
 /**
  * _nautilus_path_bar_up:
