@@ -48,12 +48,7 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkdnd.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmenubar.h>
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <libnautilus-private/nautilus-dnd.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -616,7 +611,7 @@ location_button_pressed_callback (GtkWidget      *widget,
 {
 	if (event->button == 3 &&
 	    window->content_view != NULL) {
-		nautilus_view_pop_up_location_context_menu (window->content_view, event);
+		nautilus_view_pop_up_location_context_menu (window->content_view, event, NULL);
 	}
 
 	return FALSE;
