@@ -39,10 +39,7 @@
 #include "nautilus-window-private.h"
 #include "nautilus-desktop-window.h"
 #include "nautilus-search-bar.h"
-#include <gtk/gtkmain.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkenums.h>
-#include <gtk/gtkversion.h>
+#include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-help.h>
@@ -432,7 +429,7 @@ action_about_nautilus_callback (GtkAction *action,
 		   "GNU General Public License for more details."),
 		N_("You should have received a copy of the GNU General Public License "
 		   "along with Nautilus; if not, write to the Free Software Foundation, Inc., "
-		   "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA")
+		   "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA")
 	};
 	gchar *license_trans;
 
@@ -440,17 +437,13 @@ action_about_nautilus_callback (GtkAction *action,
 					     _(license[2]), NULL);
 
 	gtk_show_about_dialog (GTK_WINDOW (user_data),
-#if GTK_CHECK_VERSION (2, 11, 0)
 			       "program-name", _("Nautilus"),
-#else
-			       "name", _("Nautilus"),
-#endif /* GTK 2.11. 0 */
 			       "version", VERSION,
 			       "comments", _("Nautilus is a graphical shell "
 					     "for GNOME that makes it "
 					     "easy to manage your files "
 					     "and the rest of your system."),
-			       "copyright", _("Copyright \xC2\xA9 1999-2007 "
+			       "copyright", _("Copyright \xC2\xA9 1999-2008 "
 					      "The Nautilus authors"),
 			       "license", license_trans,
 			       "wrap-license", TRUE,
@@ -774,76 +767,15 @@ get_extension_menus (NautilusWindow *window)
 	return items;
 }
 
-static void
-add_extension_menu_items (NautilusWindow *window,
-			  guint merge_id,
-			  GtkActionGroup *action_group,
-			  GList *menu_items,
-			  const char *subdirectory)
-{
-	GtkUIManager *ui_manager;
-	GList *l;
-
-	ui_manager = window->details->ui_manager;
-	
-	for (l = menu_items; l; l = l->next) {
-		NautilusMenuItem *item;
-		NautilusMenu *menu;
-		GtkAction *action;
-		char *path;
-		
-		item = NAUTILUS_MENU_ITEM (l->data);
-		
-		g_object_get (item, "menu", &menu, NULL);
-		
-		action = nautilus_action_from_menu_item (item);
-		gtk_action_group_add_action (action_group, action);
-		
-		path = g_build_path ("/", POPUP_PATH_EXTENSION_ACTIONS, subdirectory, NULL);
-		gtk_ui_manager_add_ui (ui_manager,
-				       merge_id,
-				       path,
-				       gtk_action_get_name (action),
-				       gtk_action_get_name (action),
-				       (menu != NULL) ? GTK_UI_MANAGER_MENU : GTK_UI_MANAGER_MENUITEM,
-				       FALSE);
-		g_free (path);
-
-		path = g_build_path ("/", MENU_PATH_EXTENSION_ACTIONS, subdirectory, NULL);
-		gtk_ui_manager_add_ui (ui_manager,
-				       merge_id,
-				       path,
-				       gtk_action_get_name (action),
-				       gtk_action_get_name (action),
-				       (menu != NULL) ? GTK_UI_MANAGER_MENU : GTK_UI_MANAGER_MENUITEM,
-				       FALSE);
-		g_free (path);
-
-		/* recursively fill the menu */		       
-		if (menu != NULL) {
-			char *subdir;
-			GList *children;
-			
-			children = nautilus_menu_get_items (menu);
-			
-			subdir = g_build_path ("/", subdirectory, "/", gtk_action_get_name (action), NULL);
-			add_extension_menu_items (window,
-						  merge_id,
-						  action_group,
-						  children,
-						  subdir);
-
-			nautilus_menu_item_list_free (children);
-			g_free (subdir);
-		}			
-	}
-}
-
 void
 nautilus_window_load_extension_menus (NautilusWindow *window)
 {
+	NautilusMenuItem *item;
 	GtkActionGroup *action_group;
+	GtkAction *action;
 	GList *items;
+	GList *l;
+	int i;
 	guint merge_id;
 
 	if (window->details->extensions_menu_merge_id != 0) {
@@ -868,12 +800,35 @@ nautilus_window_load_extension_menus (NautilusWindow *window)
 
 	items = get_extension_menus (window);
 
-	if (items != NULL) {
-		add_extension_menu_items (window, merge_id, action_group, items, "");
+	for (l = items, i = 0; l != NULL; l = l->next, i++) {
+		item = NAUTILUS_MENU_ITEM (l->data);
 
-		g_list_foreach (items, (GFunc) g_object_unref, NULL);
-		g_list_free (items);
+		action = nautilus_action_from_menu_item (item);
+		gtk_action_group_add_action (action_group,
+					     GTK_ACTION (action));
+		g_object_unref (action);
+		
+		gtk_ui_manager_add_ui (window->details->ui_manager,
+				       merge_id,
+				       MENU_PATH_EXTENSION_ACTIONS,
+				       gtk_action_get_name (action),
+				       gtk_action_get_name (action),
+				       GTK_UI_MANAGER_MENUITEM,
+				       FALSE);
+
+		gtk_ui_manager_add_ui (window->details->ui_manager,
+				       merge_id,
+				       POPUP_PATH_EXTENSION_ACTIONS,
+				       gtk_action_get_name (action),
+				       gtk_action_get_name (action),
+				       GTK_UI_MANAGER_MENUITEM,
+				       FALSE);
+
+		
+		g_object_unref (item);
 	}
+
+	g_list_free (items);
 }
 
 
